/*******************************************************************************
 * References:
 *   - http://en.wikipedia.org/wiki/Advanced_Encryption_Standard
 *   - http://csrc.nist.gov/publications/fips/fips197/fips-197.pdf
 *
 * Test vectors:
 *   - 128-bit: https://www.cosic.esat.kuleuven.be/nessie/testvectors/bc/rijndael/Rijndael-128-128.unverified.test-vectors
 *   - 192-bit: https://www.cosic.esat.kuleuven.be/nessie/testvectors/bc/rijndael/Rijndael-192-128.unverified.test-vectors
 *   - 256-bit: https://www.cosic.esat.kuleuven.be/nessie/testvectors/bc/rijndael/Rijndael-256-128.unverified.test-vectors
 *
 ******************************************************************************/

#include "AES_Small.h"

#define AES128

uint8_t block[16] = {0x00,0x11,0x22,0x33,0x44,0x55,0x66,0x77,
                     0x88,0x99,0xaa,0xbb,0xcc,0xdd,0xee,0xff};

void main() {

#ifdef AES128
   uint8_t key[16] = {0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,
                      0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f};
   aes128_t aes;

   AES128_Init(key, &aes);
   AES128_Enc(block);
   AES128_Dec(block);
#endif

#ifdef AES192
   uint8_t key[24] = {0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,
                      0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,
                      0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17};
   aes192_t aes;

   AES192_Init(key, &aes);
   AES192_Enc(block);
   AES192_Dec(block);
#endif

#ifdef AES256
   uint8_t key[32] = {0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,
                      0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,
                      0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,
                      0x18,0x19,0x1a,0x1b,0x1c,0x1d,0x1e,0x1f};
   aes256_t aes;

   AES256_Init(key, &aes);
   AES256_Enc(block);
   AES256_Dec(block);
#endif
}