/******************************************************************************
 * References:
 *   - http://en.wikipedia.org/wiki/Cyclic_redundancy_check
 *   - http://www.lammertbies.nl/comm/info/crc-calculation.html
 *   - http://www.zorc.breitbandkatze.de/crc.html
 *
 * Example:
 *
 *      Message: "123456789"
 *  CRC16-CCITT: 29b1
 *        CRC32: cbf43926
 *
 ******************************************************************************/

#include "stdint.h"

char msg[] = "123456789";
uint16_t checksum16;
uint32_t checksum32;

void main() {
   CRC16_Init(_CRC16_POLY_CCITT_NORMAL, -1);
   checksum16 = CRC16_Normal(msg, strlen(msg));
   
   CRC32_Init(_CRC32_POLY_REVERSE, -1);
   checksum32 = CRC32(msg, strlen(msg));

   // or faster (but but requires more ROM space for lookup tables)

   checksum16 = CRC16_Tab(msg, strlen(msg), -1);
   checksum32 = CRC32_Tab(msg, strlen(msg), -1);
}